# Generated by Django 6.0.2 on 2026-02-09 12:53

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0006_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="f90a341bca184781820f5ff8012bf350",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="f90a341bca184781820f5ff8012bf350",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterUniqueTogether(
            name="organizationuser",
            unique_together={("user", "organization")},
        ),
    ]
