# Generated by Django 6.0.2 on 2026-02-13 08:07

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0008_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="deliveryschedule",
            name="delivered_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="ff58446e143a4d69b7773604efeb581c",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="ff58446e143a4d69b7773604efeb581c",
                editable=False,
                max_length=32,
            ),
        ),
    ]
