# Generated by Django 6.0.1 on 2026-01-29 07:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0003_apikey_salt_imapconnection_salt"),
    ]

    operations = [
        migrations.CreateModel(
            name="JobExecution",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "job_name",
                    models.CharField(
                        choices=[("DELIVER_CONTENTS", "deliver_contents")],
                        max_length=200,
                    ),
                ),
                ("started_at", models.DateTimeField(auto_now_add=True)),
                ("finished_at", models.DateTimeField(blank=True, null=True)),
                (
                    "status",
                    models.CharField(
                        choices=[("RUNNING", "running"), ("COMPLETED", "completed")],
                        max_length=50,
                    ),
                ),
            ],
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="727829a83ebd47f8baf0c15400d16119",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="727829a83ebd47f8baf0c15400d16119",
                editable=False,
                max_length=32,
            ),
        ),
    ]
