{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-BEL5IN7j.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-BnY4rqXE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-DGyy5JNc.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-CGPZXh3G.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-BJA-Qv7d.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-u7JOT8iP.js">
    <script type="module" crossorigin src="/static/assets/command_result-BAwizanF.js"></script>
{% endblock %}
