{% extends "public/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-BEL5IN7j.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-BnY4rqXE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/RequiredTextField-egwBrnFU.js">
    <link rel="modulepreload" crossorigin href="/static/assets/utils-MPtJ5ynp.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-DGyy5JNc.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-CGPZXh3G.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-CY2FZLhF.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-CGu6k_Gi.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-BJA-Qv7d.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-u7JOT8iP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TextField-9E0h2GEt.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-DyY0x5OK.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-YO0xWqIm.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-e1vpiHuY.js">
    <script type="module" crossorigin src="/static/assets/organization-B2Lnwl_q.js"></script>
{% endblock %}
