import{o as m,j as r,n as c,B as x}from"./render-BEL5IN7j.js";import{L as d}from"./Layout-BnY4rqXE.js";import{A as e}from"./Alert-DGyy5JNc.js";import{B as l}from"./Button-CGPZXh3G.js";import"./Container-BJA-Qv7d.js";import"./Link-u7JOT8iP.js";const u=()=>{const{successMessage:t,confirmationMessage:s,confirmUrl:i,errorMessage:o,ref:a,localeMessages:n}=c();return r.jsx(d,{children:!o&&!s?r.jsx(e,{severity:"success",sx:{maxWidth:800,margin:"0 auto",backgroundColor:"background.light"},children:t}):s?r.jsxs(e,{severity:"warning",sx:{maxWidth:800,margin:"20px auto"},children:[s,r.jsx(x,{mt:2,children:r.jsx(l,{href:i,variant:"contained",mt:2,children:n.Confirm})})]}):r.jsxs(e,{severity:"error",sx:{maxWidth:800,margin:"20px auto"},children:[o," (ref: ",a,")"]})})};m({children:r.jsx(u,{})});
//# sourceMappingURL=command_result-BAwizanF.js.map
