# Generated by Django 6.0.2 on 2026-02-13 07:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_email_learning",
            "0007_alter_apikey_salt_alter_imapconnection_salt_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="24cbbf453c064d1c99017f78d01115a1",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="24cbbf453c064d1c99017f78d01115a1",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.CreateModel(
            name="Certificate",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("issued_at", models.DateTimeField(auto_now_add=True)),
                ("name_on_certificate", models.CharField(max_length=200)),
                ("random_suffix", models.IntegerField()),
                (
                    "enrollment",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="certificate",
                        to="django_email_learning.enrollment",
                    ),
                ),
            ],
        ),
    ]
