import{n as a,j as e,T as s,B as l}from"./render-BEL5IN7j.js";import{C as c}from"./Container-BJA-Qv7d.js";import{B as r}from"./Button-CGPZXh3G.js";const p=({content:n,onDelete:o,onCancel:i})=>{const{localeMessages:t}=a();return e.jsxs(c,{sx:{padding:4,textAlign:"center"},children:[e.jsx(s,{variant:"h6",gutterBottom:!0,children:t.delete_content_confirmation.replace("CONTENT_TITLE",n.title)}),e.jsxs(l,{sx:{marginTop:2},children:[e.jsx(r,{variant:"contained",color:"error",onClick:()=>o(n.id),sx:{marginRight:2},children:t.delete}),e.jsx(r,{variant:"outlined",onClick:i,children:t.cancel})]})]})};export{p as default};
//# sourceMappingURL=DeleteContentForm-BPNDyYVP.js.map
