import{g as d,a as p,r as l,u,j as g,s as x,c as C,b as D,m as f,T as m,e as v}from"./render-BEL5IN7j.js";import{a as y}from"./Dialog-CGu6k_Gi.js";function M(o){return d("MuiDialogContent",o)}p("MuiDialogContent",["root","dividers"]);function w(o){return d("MuiDialogTitle",o)}const R=p("MuiDialogTitle",["root"]),U=o=>{const{classes:t,dividers:s}=o;return D({root:["root",s&&"dividers"]},M,t)},h=x("div",{name:"MuiDialogContent",slot:"Root",overridesResolver:(o,t)=>{const{ownerState:s}=o;return[t.root,s.dividers&&t.dividers]}})(f(({theme:o})=>({flex:"1 1 auto",WebkitOverflowScrolling:"touch",overflowY:"auto",padding:"20px 24px",variants:[{props:({ownerState:t})=>t.dividers,style:{padding:"16px 24px",borderTop:`1px solid ${(o.vars||o).palette.divider}`,borderBottom:`1px solid ${(o.vars||o).palette.divider}`}},{props:({ownerState:t})=>!t.dividers,style:{[`.${R.root} + &`]:{paddingTop:0}}}]}))),F=l.forwardRef(function(t,s){const e=u({props:t,name:"MuiDialogContent"}),{className:r,dividers:n=!1,...i}=e,a={...e,dividers:n},c=U(a);return g.jsx(h,{className:C(c.root,r),ownerState:a,ref:s,...i})});function S(o){return d("MuiDialogContentText",o)}p("MuiDialogContentText",["root"]);const b=o=>{const{classes:t}=o,e=D({root:["root"]},S,t);return{...t,...e}},N=x(m,{shouldForwardProp:o=>v(o)||o==="classes",name:"MuiDialogContentText",slot:"Root"})({}),k=l.forwardRef(function(t,s){const e=u({props:t,name:"MuiDialogContentText"}),{children:r,className:n,...i}=e,a=b(i);return g.jsx(N,{component:"p",variant:"body1",color:"textSecondary",ref:s,ownerState:i,className:C(a.root,n),...e,classes:a})}),j=o=>{const{classes:t}=o;return D({root:["root"]},w,t)},$=x(m,{name:"MuiDialogTitle",slot:"Root"})({padding:"16px 24px",flex:"0 0 auto"}),B=l.forwardRef(function(t,s){const e=u({props:t,name:"MuiDialogTitle"}),{className:r,id:n,...i}=e,a=e,c=j(a),{titleId:T=n}=l.useContext(y);return g.jsx($,{component:"h2",className:C(c.root,r),ownerState:a,ref:s,variant:"h6",id:n??T,...i})});export{B as D,F as a,k as b};
//# sourceMappingURL=DialogTitle-D3yk6KnK.js.map
