# Generated by Django 6.0.1 on 2026-01-30 10:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0004_jobexecution_alter_apikey_salt_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="course",
            name="image",
            field=models.ImageField(blank=True, null=True, upload_to="course_images/"),
        ),
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="847bdf99eb494499a2dce4f279456bcd",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="847bdf99eb494499a2dce4f279456bcd",
                editable=False,
                max_length=32,
            ),
        ),
    ]
