{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-BEL5IN7j.js">
    <link rel="modulepreload" crossorigin href="/static/assets/WorkspacePremium-BpR8JYDX.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-BJA-Qv7d.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TextField-9E0h2GEt.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-DGyy5JNc.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-CGPZXh3G.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-DyY0x5OK.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-YO0xWqIm.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-e1vpiHuY.js">
    <script type="module" crossorigin src="/static/assets/certtificate_form-V_dU5z_c.js"></script>
{% endblock %}
