import{$ as x,n as p,j as u}from"./render-BEL5IN7j.js";import{T as d}from"./TextField-9E0h2GEt.js";const c=x.forwardRef(({label:e,value:o,onChange:i,error:l,helperText:s,sx:a={},...n},t)=>{const{direction:r}=p();return console.log("RequiredTextField rendered, ref:",t),u.jsx(d,{ref:t,label:e,value:o,onChange:i,error:l,helperText:s,required:!0,sx:{...a,label:{right:r==="rtl"?"25px":"auto",left:r==="rtl"?"auto":0,"&.MuiInputLabel-shrink":{right:r==="rtl"?"30px":"auto",transformOrigin:r==="rtl"?"top right":"top left",left:r==="rtl"?"auto":0}}},slotProps:{formHelperText:{sx:{color:"errorText.main",marginLeft:0}}},...n,dir:r})});export{c as R};
//# sourceMappingURL=RequiredTextField-egwBrnFU.js.map
