# Generated by Django 6.0.1 on 2026-02-02 08:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0005_course_image_alter_apikey_salt_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="9a60f001297443b3b6ac8d6cc7754ca6",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="9a60f001297443b3b6ac8d6cc7754ca6",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="learner",
            name="email",
            field=models.EmailField(max_length=254),
        ),
        migrations.AlterUniqueTogether(
            name="learner",
            unique_together={("organization", "email")},
        ),
    ]
