import{j as o,Z as e,B as a,T as t}from"./render-BEL5IN7j.js";import{C as i}from"./Container-BJA-Qv7d.js";import{L as s}from"./Link-u7JOT8iP.js";const c=({children:n})=>o.jsxs(o.Fragment,{children:[o.jsx(e,{styles:r=>({body:{margin:0,padding:0,backgroundColor:r.palette.background.dark,color:r.palette.text.primary}})}),o.jsx(i,{sx:{backgroundColor:"background.paper",padding:4,marginTop:4,borderRadius:2},children:n}),o.jsx(a,{component:"footer",sx:{position:"fixed",bottom:0,right:16,padding:1,zIndex:1e3,backgroundColor:"transparent"},children:o.jsxs(t,{variant:"caption",sx:{color:"text.secondary",fontSize:"0.7rem",opacity:.8},children:["Powered by"," ",o.jsx(s,{href:"https://github.com/AvaCodeSolutions/django-email-learning",target:"_blank",rel:"noopener noreferrer",sx:{color:"secondary.main",textDecoration:"none","&:hover":{textDecoration:"underline"}},children:"Django Email Learning"})]})})]});export{c as L};
//# sourceMappingURL=Layout-BnY4rqXE.js.map
