# Generated by Django 6.0.1 on 2026-01-29 07:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_email_learning", "0002_apikey"),
    ]

    operations = [
        migrations.AddField(
            model_name="apikey",
            name="salt",
            field=models.CharField(
                default="3e9a5a435c004a3e9a17417f21df4cdd",
                editable=False,
                max_length=32,
            ),
        ),
        migrations.AddField(
            model_name="imapconnection",
            name="salt",
            field=models.CharField(
                default="3e9a5a435c004a3e9a17417f21df4cdd",
                editable=False,
                max_length=32,
            ),
        ),
    ]
