{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}
    <h2>{{ quiz.title }}</h2>

    <p>{% translate "Dear Learner," %}</p>

    <p>{% blocktranslate with deadline_days=quiz.deadline_days %}Your quiz is now available for completion. You have <strong>{{ deadline_days }} days</strong> from today to submit your responses.{% endblocktranslate %}</p>

    <p>{% blocktranslate with score=quiz.required_score %}To successfully pass this quiz, you must achieve a minimum score of <strong>{{ score }}</strong>.{% endblocktranslate %}</p>
    <p>{% translate "Please click the link below to access and submit your quiz:" %}</p>

    <div style="text-align: center; margin: 20px 0;">
        <a href="{{ link }}" style="background-color: {{ brand_color }}; color: white; padding: 12px 24px; text-decoration: none; border-radius: 5px; display: inline-block; font-weight: bold;">
            {% translate "Start Quiz" %}
        </a>
    </div>
    <p>{% translate "Best of luck!" %}</p>
    <p style="font-size: 0.9em; color: #7f8c8d; text-align: center; margin-top: 30px;">
        {% blocktranslate %}If you wish to unsubscribe from these course, please <a href="{{ unsubscribe_link }}" style="color: {{ brand_color }}; text-decoration: none;">click here</a>{% endblocktranslate %}.
    </p>
{% endblock %}
