{% extends "emails/base.html" %}
{% load i18n %}

{% block content %}
<h2 style="color: #2c3e50; margin-top: 0; text-align: center; border-bottom: 2px solid {{ brand_color }}; padding-bottom: 15px;">{% blocktranslate %}Welcome to {{ organization }}{% endblocktranslate %}</h2>
{% translate "Hi there," %} <br /><br />

{% blocktranslate %}
You have been added as a user to the {{ organization }} platform.<br />
To get started and set up your account, please click the link below to choose your password.<br />
{% endblocktranslate %}

{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
{% endblock %}<br /><br />

{% translate "If you weren't expecting this invitation, you can safely ignore this email." %} <br /><br />
{% translate "Best regards," %} <br/>
{% blocktranslate %}The {{ organization }} team{% endblocktranslate %}
{% endblock %}
