{% extends "platform/base.html" %}

{% block extra_head %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-BEL5IN7j.js">
    <link rel="modulepreload" crossorigin href="/static/assets/LinearProgress-CxAdYH_V.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Base-B0IvxOwn.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Ballot-Ca3VSdTS.js">
    <link rel="modulepreload" crossorigin href="/static/assets/utils-MPtJ5ynp.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Delete-B4sDn-7L.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-CY2FZLhF.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-CGPZXh3G.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-YO0xWqIm.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-DyY0x5OK.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-CGu6k_Gi.js">
    <link rel="modulepreload" crossorigin href="/static/assets/SwitchBase-DFAnYP3H.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-u7JOT8iP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-e1vpiHuY.js">
    <link rel="stylesheet" href="/static/assets/course-DaNRxHni.css">
    <script type="module" crossorigin src="/static/assets/course-BVLD3ER7.js"></script>
{% endblock %}
